﻿using System.Linq;
using System.Windows;
using System.Windows.Controls;

namespace BookStoreFramework
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private BookStoreContext _context;
        public MainWindow()
        {
            InitializeComponent();
            _context = new BookStoreContext();
            Load();
        }

        private void Load()
        {
            BooksGrid.ItemsSource = _context.Books.ToList();
        }

        private void BtnInsert_Click(object sender, RoutedEventArgs e)
        {
            InsertBook(TbName.Text, TbPrice.Text, TbAuthor.Text, TbCategory.Text);
        }

        public bool InsertBook(string name, string priceStr, string author, string category)
        {
            if (!decimal.TryParse(priceStr, out decimal price))
            {
                return false;
            }

            if (string.IsNullOrWhiteSpace(name) || string.IsNullOrWhiteSpace(author) || string.IsNullOrWhiteSpace(category))
            {
                return false;
            }

            Books book = new Books()
            {
                Name = name,
                Price = price,
                Author = author,
                Category = category
            };

            _context.Books.Add(book);
            _context.SaveChanges();
            Load();

            return true;
        }

        private void BtnUpdate_Click(object sender, RoutedEventArgs e)
        {
            UpdateBook(TbName.Text, TbPrice.Text, TbAuthor.Text, TbCategory.Text);
        }

        public bool UpdateBook(string name, string priceStr, string author, string category)
        {
            if (BooksGrid.SelectedItem is Books selectedBook)
            {
                if (!decimal.TryParse(priceStr, out decimal price))
                {
                    return false;
                }

                if (string.IsNullOrWhiteSpace(name) || string.IsNullOrWhiteSpace(author) || string.IsNullOrWhiteSpace(category))
                {
                    return false;
                }

                selectedBook.Name = name;
                selectedBook.Price = price;
                selectedBook.Category = category;
                selectedBook.Author = author;
                _context.SaveChanges();
                Load();

                return true;
            }

            return false;
        }

        private void BtnDelete_Click(object sender, RoutedEventArgs e)
        {
            DeleteBook();
        }

        public void DeleteBook()
        {
            if (BooksGrid.SelectedItem is Books selectedBook)
            {
                _context.Books.Remove(selectedBook);
                _context.SaveChanges();
                Load();
            }
        }

        private void BooksGrid_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (BooksGrid.SelectedItem is Books selectedBook)
            {
                TbName.Text = selectedBook.Name;
                TbPrice.Text = selectedBook.Price.ToString();
                TbAuthor.Text = selectedBook.Author;
                TbCategory.Text = selectedBook.Category;
            }
        }
    }
}
